@@ -5,6 +5,6 @@ icon= Icon(
     hex="02569B",
     source="https://flutter.dev/brand",
     svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>Flutter icon</title><path d="M14.314 0L2.3 12 6 15.7 21.684.013h-7.357zm.014 11.072L7.857 17.53l6.47 6.47H21.7l-6.46-6.468 6.46-6.46h-7.37z"/></svg>""",
-    guidelines=None,
+    guidelines='https://flutter.dev/brand',
     license=None,
 )
