@@ -5,6 +5,6 @@ icon= Icon(
     hex="000000",
     source="https://ifttt.com/discover/brand-guidelines",
     svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>IFTTT icon</title><path d="M0 8.82h2.024v6.36H0zm11.566 0h-3.47v2.024h1.446v4.337h2.024v-4.337h1.446V8.82zm5.494 0h-3.47v2.024h1.446v4.337h2.024v-4.337h1.446V8.82zm5.494 0h-3.47v2.024h1.446v4.337h2.024v-4.337H24V8.82zM7.518 10.843V8.82H2.892v6.36h2.024v-1.734H6.65v-2.024H4.916v-.578z"/></svg>""",
-    guidelines=None,
+    guidelines='https://ifttt.com/discover/brand-guidelines',
     license=None,
 )
